==> btsbots-0.0.6.tar.gz: btsbots-0.0.6/btsbots/config.py <==
# -*- coding: utf-8 -*-

peg_asset_list = [
    "KRW", "BTC", "SILVER", "GOLD", "TRY",
    "SGD", "HKD", "RUB", "SEK", "NZD", "CNY",
    "MXN", "CAD", "CHF", "AUD", "GBP", "JPY",
    "EUR", "USD", "TCNY", "TUSD"]

pusher_prefix = "btsbots.trade"
service_account = "pay.btsbots"

asset_info = {
    'AUD': {'id': '1.3.117', 'precision': 4},
    'BOTSCNY': {'id': '1.3.338', 'precision': 4},
    'BTC': {'id': '1.3.103', 'precision': 8},
    'BTS': {'id': '1.3.0', 'precision': 5},
    'CAD': {'id': '1.3.115', 'precision': 4},
    'CHF': {'id': '1.3.116', 'precision': 4},
    'CNY': {'id': '1.3.113', 'precision': 4},
    'EUR': {'id': '1.3.120', 'precision': 4},
    'GBP': {'id': '1.3.118', 'precision': 4},
    'GOLD': {'id': '1.3.106', 'precision': 6},
    'HKD': {'id': '1.3.109', 'precision': 4},
    'JPY': {'id': '1.3.119', 'precision': 2},
    'KRW': {'id': '1.3.102', 'precision': 4},
    'METAEX.BTC': {'id': '1.3.592', 'precision': 8},
    'MXN': {'id': '1.3.114', 'precision': 4},
    'NZD': {'id': '1.3.112', 'precision': 4},
    'OPENBTC': {'id': '1.3.569', 'precision': 8},
    'RUB': {'id': '1.3.110', 'precision': 4},
    'SEK': {'id': '1.3.111', 'precision': 4},
    'SGD': {'id': '1.3.108', 'precision': 4},
    'SILVER': {'id': '1.3.105', 'precision': 4},
    'TCNY': {'id': '1.3.734', 'precision': 4},
    'TUSD': {'id': '1.3.780', 'precision': 4},
    'TRADE.BTC': {'id': '1.3.350', 'precision': 8},
    'TRY': {'id': '1.3.107', 'precision': 4},
    'USD': {'id': '1.3.121', 'precision': 4}}

==> btsbots-0.0.14.tar.gz: btsbots-0.0.14/btsbots/config.py <==
# -*- coding: utf-8 -*-

peg_asset_list = [
    "KRW", "BTC", "SILVER", "GOLD", "TRY",
    "SGD", "HKD", "RUB", "SEK", "NZD", "CNY",
    "MXN", "CAD", "CHF", "AUD", "GBP", "JPY",
    "EUR", "USD", "TCNY", "TUSD"]

pusher_prefix = "btsbots.trade"
service_account = "pay.btsbots"

asset_info = {
    'AUD': {'id': '1.3.117', 'precision': 4},
    'BOTSCNY': {'id': '1.3.338', 'precision': 4},
    'BTC': {'id': '1.3.103', 'precision': 8},
    'BTS': {'id': '1.3.0', 'precision': 5},
    'CAD': {'id': '1.3.115', 'precision': 4},
    'CHF': {'id': '1.3.116', 'precision': 4},
    'CNY': {'id': '1.3.113', 'precision': 4},
    'EUR': {'id': '1.3.120', 'precision': 4},
    'GBP': {'id': '1.3.118', 'precision': 4},
    'GOLD': {'id': '1.3.106', 'precision': 6},
    'HKD': {'id': '1.3.109', 'precision': 4},
    'JPY': {'id': '1.3.119', 'precision': 2},
    'KRW': {'id': '1.3.102', 'precision': 4},
    'METAEX.BTC': {'id': '1.3.592', 'precision': 8},
    'MXN': {'id': '1.3.114', 'precision': 4},
    'NZD': {'id': '1.3.112', 'precision': 4},
    'OPEN.BTC': {'id': '1.3.861', 'precision': 8},
    'RUB': {'id': '1.3.110', 'precision': 4},
    'SEK': {'id': '1.3.111', 'precision': 4},
    'SGD': {'id': '1.3.108', 'precision': 4},
    'SILVER': {'id': '1.3.105', 'precision': 4},
    'TCNY': {'id': '1.3.734', 'precision': 4},
    'TUSD': {'id': '1.3.780', 'precision': 4},
    'TRADE.BTC': {'id': '1.3.350', 'precision': 8},
    'TRY': {'id': '1.3.107', 'precision': 4},
    'USD': {'id': '1.3.121', 'precision': 4}}
